models.sidebar
==============

SideBarManager Class
--------------------

.. autoclass:: pykechain.models.sidebar.SideBarManager
   :members:

SideBarItem Base Class
----------------------

.. autoclass:: pykechain.models.sidebar.sidebar_base.SideBarItem
   :members:

SideBar Classes
---------------

.. autoclass:: pykechain.models.sidebar.SideBarButton
   :members:

.. autoclass:: pykechain.models.sidebar.SideBarCard
   :members:
